summaryrefslogtreecommitdiffstats
path: root/kgoldrunner/src/kgoldrunner.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kgoldrunner/src/kgoldrunner.cpp')
-rw-r--r--kgoldrunner/src/kgoldrunner.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kgoldrunner/src/kgoldrunner.cpp b/kgoldrunner/src/kgoldrunner.cpp
index 9f66123d..da4c73b3 100644
--- a/kgoldrunner/src/kgoldrunner.cpp
+++ b/kgoldrunner/src/kgoldrunner.cpp
@@ -823,14 +823,14 @@ bool KGoldrunner::getDirectories()
// WHERE THINGS ARE: In the KDE 3 environment (Release 3.1.1), application
// documentation and data files are in a directory structure given by
// $KDEDIRS (e.g. "/usr/local/kde" or "/opt/trinity/"). Application user data
// files are in a directory structure given by $KDEHOME ("$HOME/.kde").
// Within those two structures, the three sub-directories will typically be
// "share/doc/HTML/en/kgoldrunner/", "share/apps/kgoldrunner/system/" and
// "share/apps/kgoldrunner/user/". Note that it is necessary to have
// an extra path level ("system" or "user") after "kgoldrunner", otherwise
// all the KGoldrunner files have similar path names (after "apps") and
// KDE always locates directories in $KDEHOME and never the released games.
// The directory strings are set by KDE at run time and might change in
// later releases, so use them with caution and only if something gets lost.
@@ -848,7 +848,7 @@ bool KGoldrunner::getDirectories()
if (systemHTMLDir.length() <= 0) {
KGrMessage::information (this, i18n("Get Folders"),
i18n("Cannot find documentation sub-folder 'en/%1/' "
- "in area '%2' of the KDE folder ($KDEDIRS).")
+ "in area '%2' of the KDE folder ($TDEDIRS).")
.tqarg(myDir).tqarg(dirs->kde_default ("html")));
// result = FALSE; // Don't abort if the doc is missing.
}
@@ -860,7 +860,7 @@ bool KGoldrunner::getDirectories()
if (systemDataDir.length() <= 0) {
KGrMessage::information (this, i18n("Get Folders"),
i18n("Cannot find system games sub-folder '%1/system/' "
- "in area '%2' of the KDE folder ($KDEDIRS).")
+ "in area '%2' of the KDE folder ($TDEDIRS).")
.tqarg(myDir).tqarg(dirs->kde_default ("data")));
result = FALSE; // ABORT if the games data is missing.
}
@@ -873,7 +873,7 @@ bool KGoldrunner::getDirectories()
if (userDataDir.length() <= 0) {
KGrMessage::information (this, i18n("Get Folders"),
i18n("Cannot find or create user games sub-folder '%1/user/' "
- "in area '%2' of the KDE user area ($KDEHOME).")
+ "in area '%2' of the KDE user area ($TDEHOME).")
.tqarg(myDir).tqarg(dirs->kde_default ("data")));
// result = FALSE; // Don't abort if user area is missing.
}
@@ -882,7 +882,7 @@ bool KGoldrunner::getDirectories()
if (! create) {
KGrMessage::information (this, i18n("Get Folders"),
i18n("Cannot find or create 'levels/' folder in "
- "sub-folder '%1/user/' in the KDE user area ($KDEHOME).").tqarg(myDir));
+ "sub-folder '%1/user/' in the KDE user area ($TDEHOME).").tqarg(myDir));
// result = FALSE; // Don't abort if user area is missing.
}
}
@@ -823,14 +823,14 @@ bool KGoldrunner::getDirectories()
// WHERE THINGS ARE: In the KDE 3 environment (Release 3.1.1), application
// documentation and data files are in a directory structure given by
- // $KDEDIRS (e.g. "/usr/local/kde" or "/opt/trinity/"). Application user data
- // files are in a directory structure given by $KDEHOME ("$HOME/.kde").
+ // $TDEDIRS (e.g. "/usr/local/kde" or "/opt/trinity/"). Application user data
+ // files are in a directory structure given by $TDEHOME ("$HOME/.kde").
// Within those two structures, the three sub-directories will typically be
// "share/doc/HTML/en/kgoldrunner/", "share/apps/kgoldrunner/system/" and
@@ -823,14 +823,14 @@ bool KGoldrunner::getDirectories()
// an extra path level ("system" or "user") after "kgoldrunner", otherwise
// all the KGoldrunner files have similar path names (after "apps") and
- // KDE always locates directories in $KDEHOME and never the released games.
+ // KDE always locates directories in $TDEHOME and never the released games.
// The directory strings are set by KDE at run time and might change in
// later releases, so use them with caution and only if something gets lost.